package com.hypers.hypers_flutter_plugin

import android.content.Context
import androidx.annotation.NonNull;
import com.hmt.analytics.HMTAgent
import com.hmt.analytics.util.HParams

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import org.json.JSONArray
import org.json.JSONObject

/** HypersFlutterPlugin */
public class HypersFlutterPlugin : FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var mChannel: MethodChannel
    private lateinit var mContext: Context

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        mChannel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "hypers_analytics")
        mChannel.setMethodCallHandler(this);
        mContext = flutterPluginBinding.applicationContext
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "hypers_analytics")
            channel.setMethodCallHandler(HypersFlutterPlugin())
        }
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "onAction" -> {
                val actionName = call.argument<String>("actionName")
                val actionCount = call.argument<Int>("actionCount") ?: 1
                val actionParams = call.argument<Map<String, Any>>("actionParams")

                val newActionParams: HashMap<String, Any> = hashMapOf()
                actionParams?.also { map ->
                    val iterator = map.iterator();

                    while (iterator.hasNext()) {
                        var (key, value) = iterator.next();
                        if (value is HashMap<*, *>) {
                            try {
                                value = JSONObject(value.toString())
                            } catch (t: Throwable) {
                            }
                        }
                        if (value is ArrayList<*>) {
                            try {
                                value = JSONArray(value.toString())
                            } catch (t: Throwable) {
                            }
                        }
                        newActionParams.put(key, value)
                    }
                }

                actionName?.also {
                    HMTAgent.onAction(mContext, it, actionCount, toHMTParams(newActionParams))
                    result.success(null)
                }
            }
            "onActionStart" -> {
                val actionName = call.argument<String>("actionName")
                val actionId = call.argument<String>("actionId") ?: "-1"

                actionName?.also {
                    println("ActionName = $actionName")
                    println("ActionId = $actionId")
                    HMTAgent.onActionStart(mContext, it, actionId)
                    result.success(null)
                }
            }
            "onActionEnd" -> {
                val actionName = call.argument<String>("actionName")
                val actionId = call.argument<String>("actionId") ?: "-1"
                val actionParams = call.argument<Map<String, Any>>("actionParams")

                actionName?.also {
                    println("ActionName = $actionName")
                    println("ActionId = $actionId")
                    HMTAgent.onActionEnd(mContext, it, toHMTParams(actionParams), actionId)
                    result.success(null)
                }

            }
            "onResume" -> {
                val pageName = call.argument<String>("pageName")

                pageName?.also {
                    HMTAgent.onResume(mContext, pageName)
                    result.success(null)
                }
            }
            "onPause" -> {
                val pageName = call.argument<String>("pageName")
                val activityParams = call.argument<Map<String, Any>>("activityParams")

                pageName?.also {
                    HMTAgent.onPause(mContext, toHMTParams(activityParams), null, it)
                    result.success(null)
                }
            }
            "bindAccountID" -> {
                val accountId = call.argument<String>("accountId")

                accountId?.also {
                    HMTAgent.bindAccountID(mContext, it)
                    result.success(null)
                }
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    private fun toHMTParams(map: Map<String, Any>?): HParams? {
        if (map != null && map.size > 0) {
            val hParams = HParams()
            hParams.setParams(map)
            return hParams
        } else {
            return null
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        mChannel.setMethodCallHandler(null)
    }
}
