#import "HypersFlutterPlugin.h"
#import "HMTAgentSDK.h"

@implementation HypersFlutterPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    //初始化SDK
    NSString *appkey = @"UA-test-ios";
    NSString *appChannel = @"App Store";
    [HMTAgentSDK initWithAppKey:appkey channel:appChannel reportPolicy:HMT_REALTIME unTracked:nil];
    
    FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"hypers_analytics"
            binaryMessenger:[registrar messenger]];
    HypersFlutterPlugin* instance = [[HypersFlutterPlugin alloc] init];
    [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSLog(@"%@",call.arguments);
    //发送自定义事件
    if ([@"onAction" isEqualToString:call.method]) {
        [self postAction:call];
    }
  
    //自定义持续事件开始
    if ([@"onActionStart" isEqualToString:call.method]) {
        [self postKeepAction:call isStart:YES];
    }
  
    //自定义持续事件结束
    if ([@"onActionEnd" isEqualToString:call.method]) {
        [self postKeepAction:call isStart:NO];
    }
  
    //页面开始
    if ([@"onResume" isEqualToString:call.method]) {
        [self postActivity:call isStart:YES];
    }
  
    //页面结束
    if ([@"onPause" isEqualToString:call.method]) {
        [self postActivity:call isStart:NO];
    }
  
    //绑定账户ID
    if ([@"bindAccountID" isEqualToString:call.method]) {
        [self bindAccountID:call];
    }
}

- (void)postAction:(FlutterMethodCall *)call{
    NSString *actionName = call.arguments[@"actionName"] ? call.arguments[@"actionName"] : @"PostActionName";
    NSNumber *actionCount = call.arguments[@"actionCount"] ? call.arguments[@"actionCount"] : [NSNumber numberWithInt:1];
    NSDictionary *actionParams = call.arguments[@"actionParams"] ? call.arguments[@"actionParams"] : nil;

    [HMTAgentSDK postAction:actionName acc:[actionCount intValue] property:actionParams callback:nil];
}

- (void)postKeepAction:(FlutterMethodCall *)call isStart:(bool)isStart{
    NSString *actionName = call.arguments[@"actionName"] ? call.arguments[@"actionName"] : @"PostActionName";
    NSString *uactSign = call.arguments[@"uactSign"] ? call.arguments[@"uactSign"] : @"uactSign";
    NSDictionary *actionParams = call.arguments[@"actionParams"] ? call.arguments[@"actionParams"] : nil;

    if(isStart){
        [HMTAgentSDK postActionStart:actionName uactSign:uactSign];
    }else{
        [HMTAgentSDK postActionEnd:actionName uactSign:uactSign property:actionParams callback:nil];
    }
}

- (void)postActivity:(FlutterMethodCall *)call isStart:(bool)isStart{
    NSString *pageName = call.arguments[@"pageName"] ? call.arguments[@"pageName"] : @"pageName";
    NSDictionary *actionParams = call.arguments[@"actionParams"] ? call.arguments[@"actionParams"] : nil;

    if (isStart) {
        [HMTAgentSDK startTracPage:pageName];
    }else{
        [HMTAgentSDK endTracPage:actionParams];
    }
}

- (void)bindAccountID:(FlutterMethodCall *)call{
    NSString *accountID = call.arguments[@"accountId"] ? call.arguments[@"accountId"] : nil;
    if (accountID) {
        [HMTAgentSDK bindAccountId:accountID];
    }
}


@end
