import 'dart:async';

import 'package:flutter/services.dart';

class HMTFlutterAgent {
  static const MethodChannel platform = const MethodChannel('hypers_analytics');

  ///
  ///  自定义事件
  ///
  static Future<Null> sendAction(String actionName,
      {int actionCount, Map<String, dynamic> actionParams}) async {
    Map<String, dynamic> args = {"actionName": actionName};
    if (actionCount != null) {
      args['actionCount'] = actionCount;
    }
    if (actionParams != null) {
      args['actionParams'] = actionParams;
    }
    return await platform.invokeMethod("onAction", args);
  }

  ///
  /// 自定义连续事件(开始)
  ///
  static Future<Null> sendActionStart(String actionName,
      {String actionId = "-1"}) async {
    Map<String, dynamic> args = <String, dynamic>{};
    if (actionName != null) {
      args["actionName"] = actionName;
    }
    if (actionId != null) {
      args["actionId"] = actionId;
    }
    return await platform.invokeMethod("onActionStart", args);
  }

  ///
  /// 自定义连续事件(结束)
  ///
  static Future<Null> sendActionEnd(String actionName,
      {String actionId = "-1", Map<String, dynamic> actionParams}) async {
    Map<String, dynamic> args = <String, dynamic>{};
    if (actionName != null) {
      args["actionName"] = actionName;
    }
    if (actionId != null) {
      args["actionId"] = actionId;
    }
    if (actionParams != null) {
      args['actionParams'] = actionParams;
    }
    return await platform.invokeMethod("onActionEnd", args);
  }

  ///
  /// 进入页面
  ///
  static Future<Null> sendActivityStart(String pageName) async {
    Map<String, dynamic> args = <String, dynamic>{};
    if (pageName != null) {
      args["pageName"] = pageName;
    }
    return await platform.invokeMethod("onResume", args);
  }

  ///
  /// 退出页面
  ///
  static Future<Null> sendActivityEnd(String pageName,
      {Map<String, dynamic> activityParams}) async {
    Map<String, dynamic> args = <String, dynamic>{};
    if (pageName != null) {
      args["pageName"] = pageName;
    }
    if (activityParams != null) {
      args["activityParams"] = activityParams;
    }
    return await platform.invokeMethod("onPause", args);
  }

  ///
  /// 绑定用户id
  ///
  static Future<Null> identify(String accountId) async {
    Map<String, dynamic> args = <String, dynamic>{};
    if (accountId != null) {
      args["accountId"] = accountId;
    }
    return await platform.invokeMethod("bindAccountID", args);
  }
}
